==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/NamespaceIpFilterRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin

import com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs.builder
import com.pulumi.azurenative.eventhub.kotlin.enums.IPAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Single item in a List or Get IpFilterRules operation
 * Azure REST API version: 2018-01-01-preview. Prior API version in Azure Native 1.x: 2018-01-01-preview.
 * ## Example Usage
 * ### NameSpaceIpFilterRuleCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var namespaceIpFilterRule = new AzureNative.EventHub.NamespaceIpFilterRule("namespaceIpFilterRule", new()
 *     {
 *         Action = "Accept",
 *         FilterName = "sdk-IPFilterRules-7337",
 *         IpFilterRuleName = "sdk-IPFilterRules-7337",
 *         IpMask = "13.78.143.246/32",
 *         NamespaceName = "sdk-Namespace-5232",
 *         ResourceGroupName = "ResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/eventhub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := eventhub.NewNamespaceIpFilterRule(ctx, "namespaceIpFilterRule", &eventhub.NamespaceIpFilterRuleArgs{
 * 			Action:            pulumi.String("Accept"),
 * 			FilterName:        pulumi.String("sdk-IPFilterRules-7337"),
 * 			IpFilterRuleName:  pulumi.String("sdk-IPFilterRules-7337"),
 * 			IpMask:            pulumi.String("13.78.143.246/32"),
 * 			NamespaceName:     pulumi.String("sdk-Namespace-5232"),
 * 			ResourceGroupName: pulumi.String("ResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.eventhub.NamespaceIpFilterRule;
 * import com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var namespaceIpFilterRule = new NamespaceIpFilterRule("namespaceIpFilterRule", NamespaceIpFilterRuleArgs.builder()
 *             .action("Accept")
 *             .filterName("sdk-IPFilterRules-7337")
 *             .ipFilterRuleName("sdk-IPFilterRules-7337")
 *             .ipMask("13.78.143.246/32")
 *             .namespaceName("sdk-Namespace-5232")
 *             .resourceGroupName("ResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:eventhub:NamespaceIpFilterRule sdk-IPFilterRules-7337 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventHub/namespaces/{namespaceName}/ipfilterrules/{ipFilterRuleName}
 * ```
 * @property action The IP Filter Action
 * @property filterName IP Filter name
 * @property ipFilterRuleName The IP Filter Rule name.
 * @property ipMask IP Mask
 * @property namespaceName The Namespace name
 * @property resourceGroupName Name of the resource group within the azure subscription.
 */
public data class NamespaceIpFilterRuleArgs(
    public val action: Output<Either<String, IPAction>>? = null,
    public val filterName: Output<String>? = null,
    public val ipFilterRuleName: Output<String>? = null,
    public val ipMask: Output<String>? = null,
    public val namespaceName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs =
        com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .filterName(filterName?.applyValue({ args0 -> args0 }))
            .ipFilterRuleName(ipFilterRuleName?.applyValue({ args0 -> args0 }))
            .ipMask(ipMask?.applyValue({ args0 -> args0 }))
            .namespaceName(namespaceName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NamespaceIpFilterRuleArgs].
 */
@PulumiTagMarker
public class NamespaceIpFilterRuleArgsBuilder internal constructor() {
    private var action: Output<Either<String, IPAction>>? = null

    private var filterName: Output<String>? = null

    private var ipFilterRuleName: Output<String>? = null

    private var ipMask: Output<String>? = null

    private var namespaceName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    /**
     * @param value The IP Filter Action
     */
    @JvmName("pboqgfthrupapdak")
    public suspend fun action(`value`: Output<Either<String, IPAction>>) {
        this.action = value
    }

    /**
     * @param value IP Filter name
     */
    @JvmName("edeflbyygxrgfatg")
    public suspend fun filterName(`value`: Output<String>) {
        this.filterName = value
    }

    /**
     * @param value The IP Filter Rule name.
     */
    @JvmName("idjkykmvfridcuqd")
    public suspend fun ipFilterRuleName(`value`: Output<String>) {
        this.ipFilterRuleName = value
    }

    /**
     * @param value IP Mask
     */
    @JvmName("ldfdlkwiibbiirob")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("alyqjxkuurroxpgc")
    public suspend fun namespaceName(`value`: Output<String>) {
        this.namespaceName = value
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("sopflilbvldmtqhy")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("kdfwhudgigsmaokl")
    public suspend fun action(`value`: Either<String, IPAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("xhjfegmpmmexladb")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("npsyxvlsnkjuojur")
    public fun action(`value`: IPAction) {
        val toBeMapped = Either.ofRight<String, IPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value IP Filter name
     */
    @JvmName("tdekrqictgdleqcq")
    public suspend fun filterName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filterName = mapped
    }

    /**
     * @param value The IP Filter Rule name.
     */
    @JvmName("fxbmxvqmhghteejd")
    public suspend fun ipFilterRuleName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipFilterRuleName = mapped
    }

    /**
     * @param value IP Mask
     */
    @JvmName("wqpebdrkquxnmpvd")
    public suspend fun ipMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("qbpfabswwrnxgapt")
    public suspend fun namespaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespaceName = mapped
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("gvuhunvgjeaxvrsg")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    internal fun build(): NamespaceIpFilterRuleArgs = NamespaceIpFilterRuleArgs(
        action = action,
        filterName = filterName,
        ipFilterRuleName = ipFilterRuleName,
        ipMask = ipMask,
        namespaceName = namespaceName,
        resourceGroupName = resourceGroupName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventhub/kotlin/NamespaceIpFilterRuleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventhub.kotlin

import com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs.builder
import com.pulumi.azurenative.eventhub.kotlin.enums.IPAction
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Single item in a List or Get IpFilterRules operation
 * Azure REST API version: 2018-01-01-preview. Prior API version in Azure Native 1.x: 2018-01-01-preview.
 * ## Example Usage
 * ### NameSpaceIpFilterRuleCreate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var namespaceIpFilterRule = new AzureNative.EventHub.NamespaceIpFilterRule("namespaceIpFilterRule", new()
 *     {
 *         Action = "Accept",
 *         FilterName = "sdk-IPFilterRules-7337",
 *         IpFilterRuleName = "sdk-IPFilterRules-7337",
 *         IpMask = "13.78.143.246/32",
 *         NamespaceName = "sdk-Namespace-5232",
 *         ResourceGroupName = "ResourceGroup",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/eventhub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := eventhub.NewNamespaceIpFilterRule(ctx, "namespaceIpFilterRule", &eventhub.NamespaceIpFilterRuleArgs{
 * 			Action:            pulumi.String("Accept"),
 * 			FilterName:        pulumi.String("sdk-IPFilterRules-7337"),
 * 			IpFilterRuleName:  pulumi.String("sdk-IPFilterRules-7337"),
 * 			IpMask:            pulumi.String("13.78.143.246/32"),
 * 			NamespaceName:     pulumi.String("sdk-Namespace-5232"),
 * 			ResourceGroupName: pulumi.String("ResourceGroup"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.eventhub.NamespaceIpFilterRule;
 * import com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var namespaceIpFilterRule = new NamespaceIpFilterRule("namespaceIpFilterRule", NamespaceIpFilterRuleArgs.builder()
 *             .action("Accept")
 *             .filterName("sdk-IPFilterRules-7337")
 *             .ipFilterRuleName("sdk-IPFilterRules-7337")
 *             .ipMask("13.78.143.246/32")
 *             .namespaceName("sdk-Namespace-5232")
 *             .resourceGroupName("ResourceGroup")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:eventhub:NamespaceIpFilterRule sdk-IPFilterRules-7337 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.EventHub/namespaces/{namespaceName}/ipfilterrules/{ipFilterRuleName}
 * ```
 * @property action The IP Filter Action
 * @property filterName IP Filter name
 * @property ipFilterRuleName The IP Filter Rule name.
 * @property ipMask IP Mask
 * @property namespaceName The Namespace name
 * @property resourceGroupName Name of the resource group within the azure subscription.
 */
public data class NamespaceIpFilterRuleArgs(
    public val action: Output<Either<String, IPAction>>? = null,
    public val filterName: Output<String>? = null,
    public val ipFilterRuleName: Output<String>? = null,
    public val ipMask: Output<String>? = null,
    public val namespaceName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs> {
    override fun toJava(): com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs =
        com.pulumi.azurenative.eventhub.NamespaceIpFilterRuleArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .filterName(filterName?.applyValue({ args0 -> args0 }))
            .ipFilterRuleName(ipFilterRuleName?.applyValue({ args0 -> args0 }))
            .ipMask(ipMask?.applyValue({ args0 -> args0 }))
            .namespaceName(namespaceName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NamespaceIpFilterRuleArgs].
 */
@PulumiTagMarker
public class NamespaceIpFilterRuleArgsBuilder internal constructor() {
    private var action: Output<Either<String, IPAction>>? = null

    private var filterName: Output<String>? = null

    private var ipFilterRuleName: Output<String>? = null

    private var ipMask: Output<String>? = null

    private var namespaceName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    /**
     * @param value The IP Filter Action
     */
    @JvmName("akuolkfqqankxkty")
    public suspend fun action(`value`: Output<Either<String, IPAction>>) {
        this.action = value
    }

    /**
     * @param value IP Filter name
     */
    @JvmName("emtwbycowlivdkpf")
    public suspend fun filterName(`value`: Output<String>) {
        this.filterName = value
    }

    /**
     * @param value The IP Filter Rule name.
     */
    @JvmName("drpwjnqojyjgliru")
    public suspend fun ipFilterRuleName(`value`: Output<String>) {
        this.ipFilterRuleName = value
    }

    /**
     * @param value IP Mask
     */
    @JvmName("cyxkeeinbqywqgav")
    public suspend fun ipMask(`value`: Output<String>) {
        this.ipMask = value
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("hnutvwvxkqrwbbys")
    public suspend fun namespaceName(`value`: Output<String>) {
        this.namespaceName = value
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("qtpeedmithrarrvi")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("dxdmbklbjuwtesmy")
    public suspend fun action(`value`: Either<String, IPAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("ikqevunuquxwrliq")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value The IP Filter Action
     */
    @JvmName("iyrebybbnpakseog")
    public fun action(`value`: IPAction) {
        val toBeMapped = Either.ofRight<String, IPAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value IP Filter name
     */
    @JvmName("tydvxwhqcntorhqt")
    public suspend fun filterName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filterName = mapped
    }

    /**
     * @param value The IP Filter Rule name.
     */
    @JvmName("qwncgnfvdbfvlrlr")
    public suspend fun ipFilterRuleName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipFilterRuleName = mapped
    }

    /**
     * @param value IP Mask
     */
    @JvmName("vuooeagmadbyxbhd")
    public suspend fun ipMask(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipMask = mapped
    }

    /**
     * @param value The Namespace name
     */
    @JvmName("fgkdxufwekhyvtmy")
    public suspend fun namespaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespaceName = mapped
    }

    /**
     * @param value Name of the resource group within the azure subscription.
     */
    @JvmName("fyoyscwchudwtdtx")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    internal fun build(): NamespaceIpFilterRuleArgs = NamespaceIpFilterRuleArgs(
        action = action,
        filterName = filterName,
        ipFilterRuleName = ipFilterRuleName,
        ipMask = ipMask,
        namespaceName = namespaceName,
        resourceGroupName = resourceGroupName,
    )
}
